<template>
  <PageWrapper :title="t('储区')">
    <CollapseContainer :title="t('配置参数')">
      <BasicForm @register="register" @submit="handleSubmit" />
    </CollapseContainer>
  </PageWrapper>
</template>
<script lang="ts">
import { defineComponent, onMounted, unref } from 'vue';
import { BasicForm, FormSchema, useForm } from '/@/components/Form/index';
import { CollapseContainer } from '/@/components/Container';
import { useMessage } from '/@/hooks/web/useMessage';
import { PageWrapper } from '/@/components/Page';
import { SaveRegion } from '/@/api/tigerapi/wms/house';
import { useI18n } from '/@/hooks/web/useI18n';
const { t } = useI18n('WMS.WareHouse');
const schemas: FormSchema[] = [
{
      field: 'CREATE_TIME',
      component: 'Input',
      label: '创建时间',
      colProps: {
        span: 24,
      },
      show:false
    },
    {
      field: 'CREATE_USER',
      component: 'Input',
      label: '创建人',
      colProps: {
        span: 24,
      },
      show:false
    },
    {
      field: 'UPDATE_TIME',
      component: 'Input',
      label: '修改时间',
      colProps: {
        span: 24,
      },
      show:false
    },
    {
      field: 'UPDATE_USER',
      component: 'Input',
      label: '修改人',
      colProps: {
        span: 24,
      },
      show:false
    },
  {
    field: 'REGION_CODE',
    component: 'Input',
    label: t('储区代码'),
    colProps: {
      span: 8,
    },
    dynamicDisabled:true,
    required: true,
  },
  {
    field: 'REGION_NAME',
    component: 'Input',
    label: t('储区名称'),
    colProps: {
      span: 8,
    },
    required: true,
  },
  {
    field: 'REMARK',
    component: 'Input',
    label: t('备注'),
    colProps: {
      span: 8,
    },
    required: false,
  },
  {
    field: 'ID',
    label: 'ID',
    required: true,
    defaultValue: 0,
    component: 'InputNumber',
    show: false,
  },
  {
    field: 'WH_ID',
    label: 'WH_ID',
    required: true,
    defaultValue: 0,
    component: 'Input',
    show: false,
  },
  {
    field: 'ORG_CODE',
    label: 'ORG_CODE',
    required: true,
    defaultValue: 0,
    component: 'Input',
    show: false,
  },
  {
    field: 'AUTH_ORG',
    label: 'AUTH_ORG',
    required: true,
    defaultValue: 0,
    component: 'Input',
    show: false,
  },
  {
    field: 'IS_ACTIVE',
    component: 'RadioGroup',
    label: t('是否启用'),
    colProps: {
      span: 12,
    },
    required: true,
    componentProps: {
      options: [
        {
          label: 'Y',
          value: 'Y',
        },
        {
          label: 'N',
          value: 'N',
        },
      ],
    },
    rules: [{ required: false, message: t('覆盖默认生成的校验信息') }],
  },
];

export default defineComponent({
  components: { BasicForm, CollapseContainer, PageWrapper },
  props: {
    data: {
      type: Object,
      //default: () => ({}),
    }
  },
  emit: ['success', 'register'],
  setup(props, { emit }) {
    const { createMessage } = useMessage();
    const [
      register,
      { validateFields, clearValidate, getFieldsValue, resetFields, setFieldsValue },
    ] = useForm({
      submitButtonOptions: { text: t('保存') },
      showResetButton: false,
      labelWidth: 120,
      schemas,
      canResize:true,
      actionColOptions: {
        span: 24,
      },
    });
    async function validateForm() {
      try {
        const res = await validateFields();
        console.log('passing', res);
      } catch (error) {
        console.log('not passing', error);
      }
    }
    async function resetValidate() {
      clearValidate();
    }
    function getFormValues() {
      const values = getFieldsValue();
      createMessage.success('values:' + JSON.stringify(values));
    }
    // 自动请求并暴露内部方法
    onMounted(() => {
      setFormValues()
    });
    function setFormValues() {
      setFieldsValue({
        ID: props.data[0]?.ID,
        REGION_CODE: props.data[0]?.REGION_CODE,
        REGION_NAME: props.data[0]?.REGION_NAME,
        IS_ACTIVE: props.data[0]?.IS_ACTIVE,
        ORG_CODE: props.data[0]?.ORG_CODE,
        AUTH_ORG: props.data[0]?.AUTH_ORG,
        WH_ID: props.data[0]?.WH_ID,
        CREATE_USER: props.data[0].CREATE_USER,
        CREATE_TIME:props.data[0].CREATE_TIME,
        REMARK: props.data[0]?.REMARK,
      });
    }
    function handleSubmit(values: any) {
        //createMessage.success('click search,values:' + JSON.stringify(values));
        const apiAction = SaveRegion(values, true)
        apiAction.then((action) => {
          if (action.IsSuccessed) {
            createMessage.success(t('保存成功'));
            emit('success', {
              isUpdate: unref(false),

              values: { ...values, id: 0 },
            });
          } else {
            createMessage.error(t('保存失败'));
          }
        })
      }
    return {
      register,
      schemas,
      handleSubmit,
      getFormValues,
      setFormValues,
      validateForm,
      resetValidate,
      resetFields,
      props,t
    };
  },
});
</script>
